==> haskell-system-fileio-0.3.16.4-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: system-fileio
version: 0.3.16.4
id: system-fileio-0.3.16.4-5xVSiL4JxmRAUXr8Ufmvn2
key: system-fileio-0.3.16.4-5xVSiL4JxmRAUXr8Ufmvn2
license: MIT
maintainer: FP Complete <michael@fpcomplete.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://github.com/fpco/haskell-filesystem
synopsis: Consistent filesystem interaction across GHC versions (deprecated)
description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx
category: System
abi: 8ffe2bb9f09cc49f2251da84af908ed6
exposed: True
exposed-modules:
    Filesystem
import-dirs: /usr/lib/ghc-8.6.5/site-local/system-fileio-0.3.16.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/system-fileio-0.3.16.4
hs-libraries: HSsystem-fileio-0.3.16.4-5xVSiL4JxmRAUXr8Ufmvn2
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    system-filepath-0.4.14-GStLucmxMDgJ6I3eQ2JLLu text-1.2.3.1
    time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock
haddock-html: /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-fileio-0.3.16.4-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: system-fileio
version: 0.3.16.4
id: system-fileio-0.3.16.4-12uUDFqX7NT9TMK4JAKZnN
key: system-fileio-0.3.16.4-12uUDFqX7NT9TMK4JAKZnN
license: MIT
maintainer: FP Complete <michael@fpcomplete.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://github.com/fpco/haskell-filesystem
synopsis: Consistent filesystem interaction across GHC versions (deprecated)
description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx
category: System
abi: 8219730eafcff5332fe98ae54ea4c2b9
exposed: True
exposed-modules:
    Filesystem
import-dirs: /usr/lib/ghc-8.6.5/site-local/system-fileio-0.3.16.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/system-fileio-0.3.16.4
hs-libraries: HSsystem-fileio-0.3.16.4-12uUDFqX7NT9TMK4JAKZnN
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    system-filepath-0.4.14-8V9CH9ujwNBBydA2SorUtz text-1.2.3.1
    time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock
haddock-html: /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
